
# Type: specificity quantifier




URI: [biolink:SpecificityQuantifier](https://w3id.org/biolink/vocab/SpecificityQuantifier)


![img](http://yuml.me/diagram/nofunky;dir:TB/class/[SpecificityQuantifier]^-[PathognomonicityQuantifier],%20[RelationshipQuantifier]^-[SpecificityQuantifier])

## Parents

 *  is_a: [RelationshipQuantifier](RelationshipQuantifier.md)

## Children

 * [PathognomonicityQuantifier](PathognomonicityQuantifier.md) - A relationship quantifier between a variant or symptom and a disease, which is high when the presence of the feature implies the existence of the disease

## Referenced by class


## Attributes

